@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<I2SCONF_SPEC>> for R {
+impl From<crate::R<I2SCONF_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<I2SCONF_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<I2SCONF_SPEC>> for W {
+impl From<crate::W<I2SCONF_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<I2SCONF_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<I2SCONF_SPEC>> for W {
 #[doc = "Field `I2S_BCK_DIV_NUM` reader - "]
 pub struct I2S_BCK_DIV_NUM_R(crate::FieldReader<u8, u8>);
 impl I2S_BCK_DIV_NUM_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_BCK_DIV_NUM_R(crate::FieldReader::new(bits))
     }
@@ -54,13 +57,14 @@ impl<'a> I2S_BCK_DIV_NUM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x3f << 22)) | (((value as u32) & 0x3f) << 22);
+        self.w.bits = (self.w.bits & !(0x3f << 22)) | ((value as u32 & 0x3f) << 22);
         self.w
     }
 }
 #[doc = "Field `I2S_CLKM_DIV_NUM` reader - "]
 pub struct I2S_CLKM_DIV_NUM_R(crate::FieldReader<u8, u8>);
 impl I2S_CLKM_DIV_NUM_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_CLKM_DIV_NUM_R(crate::FieldReader::new(bits))
     }
@@ -80,13 +84,14 @@ impl<'a> I2S_CLKM_DIV_NUM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x3f << 16)) | (((value as u32) & 0x3f) << 16);
+        self.w.bits = (self.w.bits & !(0x3f << 16)) | ((value as u32 & 0x3f) << 16);
         self.w
     }
 }
 #[doc = "Field `I2S_BITS_MOD` reader - "]
 pub struct I2S_BITS_MOD_R(crate::FieldReader<u8, u8>);
 impl I2S_BITS_MOD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_BITS_MOD_R(crate::FieldReader::new(bits))
     }
@@ -106,13 +111,14 @@ impl<'a> I2S_BITS_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 12)) | (((value as u32) & 0x0f) << 12);
+        self.w.bits = (self.w.bits & !(0x0f << 12)) | ((value as u32 & 0x0f) << 12);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_MSB_SHIFT` reader - "]
 pub struct I2S_RECE_MSB_SHIFT_R(crate::FieldReader<bool, bool>);
 impl I2S_RECE_MSB_SHIFT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_RECE_MSB_SHIFT_R(crate::FieldReader::new(bits))
     }
@@ -142,13 +148,14 @@ impl<'a> I2S_RECE_MSB_SHIFT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_MSB_SHIFT` reader - "]
 pub struct I2S_TRANS_MSB_SHIFT_R(crate::FieldReader<bool, bool>);
 impl I2S_TRANS_MSB_SHIFT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_TRANS_MSB_SHIFT_R(crate::FieldReader::new(bits))
     }
@@ -178,13 +185,14 @@ impl<'a> I2S_TRANS_MSB_SHIFT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
 #[doc = "Field `I2S_I2S_RX_START` reader - "]
 pub struct I2S_I2S_RX_START_R(crate::FieldReader<bool, bool>);
 impl I2S_I2S_RX_START_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_I2S_RX_START_R(crate::FieldReader::new(bits))
     }
@@ -214,13 +222,14 @@ impl<'a> I2S_I2S_RX_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
 #[doc = "Field `I2S_I2S_TX_START` reader - "]
 pub struct I2S_I2S_TX_START_R(crate::FieldReader<bool, bool>);
 impl I2S_I2S_TX_START_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_I2S_TX_START_R(crate::FieldReader::new(bits))
     }
@@ -250,13 +259,14 @@ impl<'a> I2S_I2S_TX_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
 #[doc = "Field `I2S_MSB_RIGHT` reader - "]
 pub struct I2S_MSB_RIGHT_R(crate::FieldReader<bool, bool>);
 impl I2S_MSB_RIGHT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_MSB_RIGHT_R(crate::FieldReader::new(bits))
     }
@@ -286,13 +296,14 @@ impl<'a> I2S_MSB_RIGHT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
 #[doc = "Field `I2S_RIGHT_FIRST` reader - "]
 pub struct I2S_RIGHT_FIRST_R(crate::FieldReader<bool, bool>);
 impl I2S_RIGHT_FIRST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_RIGHT_FIRST_R(crate::FieldReader::new(bits))
     }
@@ -322,13 +333,14 @@ impl<'a> I2S_RIGHT_FIRST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_SLAVE_MOD` reader - "]
 pub struct I2S_RECE_SLAVE_MOD_R(crate::FieldReader<bool, bool>);
 impl I2S_RECE_SLAVE_MOD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_RECE_SLAVE_MOD_R(crate::FieldReader::new(bits))
     }
@@ -358,13 +370,14 @@ impl<'a> I2S_RECE_SLAVE_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_SLAVE_MOD` reader - "]
 pub struct I2S_TRANS_SLAVE_MOD_R(crate::FieldReader<bool, bool>);
 impl I2S_TRANS_SLAVE_MOD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_TRANS_SLAVE_MOD_R(crate::FieldReader::new(bits))
     }
@@ -394,13 +407,14 @@ impl<'a> I2S_TRANS_SLAVE_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
 #[doc = "Field `I2S_I2S_RX_FIFO_RESET` reader - "]
 pub struct I2S_I2S_RX_FIFO_RESET_R(crate::FieldReader<bool, bool>);
 impl I2S_I2S_RX_FIFO_RESET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_I2S_RX_FIFO_RESET_R(crate::FieldReader::new(bits))
     }
@@ -430,13 +444,14 @@ impl<'a> I2S_I2S_RX_FIFO_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
 #[doc = "Field `I2S_I2S_TX_FIFO_RESET` reader - "]
 pub struct I2S_I2S_TX_FIFO_RESET_R(crate::FieldReader<bool, bool>);
 impl I2S_I2S_TX_FIFO_RESET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_I2S_TX_FIFO_RESET_R(crate::FieldReader::new(bits))
     }
@@ -466,13 +481,14 @@ impl<'a> I2S_I2S_TX_FIFO_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
 #[doc = "Field `I2S_I2S_RX_RESET` reader - "]
 pub struct I2S_I2S_RX_RESET_R(crate::FieldReader<bool, bool>);
 impl I2S_I2S_RX_RESET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_I2S_RX_RESET_R(crate::FieldReader::new(bits))
     }
@@ -502,13 +518,14 @@ impl<'a> I2S_I2S_RX_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
 #[doc = "Field `I2S_I2S_TX_RESET` reader - "]
 pub struct I2S_I2S_TX_RESET_R(crate::FieldReader<bool, bool>);
 impl I2S_I2S_TX_RESET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_I2S_TX_RESET_R(crate::FieldReader::new(bits))
     }
@@ -538,7 +555,7 @@ impl<'a> I2S_I2S_TX_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -696,6 +713,7 @@ impl W {
         I2S_I2S_TX_RESET_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
