@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<I2STIMING_SPEC>> for R {
+impl From<crate::R<I2STIMING_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<I2STIMING_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<I2STIMING_SPEC>> for W {
+impl From<crate::W<I2STIMING_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<I2STIMING_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<I2STIMING_SPEC>> for W {
 #[doc = "Field `I2S_TRANS_BCK_IN_INV` reader - "]
 pub struct I2S_TRANS_BCK_IN_INV_R(crate::FieldReader<bool, bool>);
 impl I2S_TRANS_BCK_IN_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_TRANS_BCK_IN_INV_R(crate::FieldReader::new(bits))
     }
@@ -64,13 +67,14 @@ impl<'a> I2S_TRANS_BCK_IN_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_DSYNC_SW` reader - "]
 pub struct I2S_RECE_DSYNC_SW_R(crate::FieldReader<bool, bool>);
 impl I2S_RECE_DSYNC_SW_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_RECE_DSYNC_SW_R(crate::FieldReader::new(bits))
     }
@@ -100,13 +104,14 @@ impl<'a> I2S_RECE_DSYNC_SW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_DSYNC_SW` reader - "]
 pub struct I2S_TRANS_DSYNC_SW_R(crate::FieldReader<bool, bool>);
 impl I2S_TRANS_DSYNC_SW_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S_TRANS_DSYNC_SW_R(crate::FieldReader::new(bits))
     }
@@ -136,13 +141,14 @@ impl<'a> I2S_TRANS_DSYNC_SW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_BCK_OUT_DELAY` reader - "]
 pub struct I2S_RECE_BCK_OUT_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_RECE_BCK_OUT_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_RECE_BCK_OUT_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -162,13 +168,14 @@ impl<'a> I2S_RECE_BCK_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | (((value as u32) & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_WS_OUT_DELAY` reader - "]
 pub struct I2S_RECE_WS_OUT_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_RECE_WS_OUT_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_RECE_WS_OUT_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -188,13 +195,14 @@ impl<'a> I2S_RECE_WS_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | (((value as u32) & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_SD_OUT_DELAY` reader - "]
 pub struct I2S_TRANS_SD_OUT_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_TRANS_SD_OUT_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_TRANS_SD_OUT_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -214,13 +222,14 @@ impl<'a> I2S_TRANS_SD_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | (((value as u32) & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_WS_OUT_DELAY` reader - "]
 pub struct I2S_TRANS_WS_OUT_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_TRANS_WS_OUT_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_TRANS_WS_OUT_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -240,13 +249,14 @@ impl<'a> I2S_TRANS_WS_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | (((value as u32) & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_BCK_OUT_DELAY` reader - "]
 pub struct I2S_TRANS_BCK_OUT_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_TRANS_BCK_OUT_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_TRANS_BCK_OUT_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -266,13 +276,14 @@ impl<'a> I2S_TRANS_BCK_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | (((value as u32) & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_SD_IN_DELAY` reader - "]
 pub struct I2S_RECE_SD_IN_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_RECE_SD_IN_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_RECE_SD_IN_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -292,13 +303,14 @@ impl<'a> I2S_RECE_SD_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | (((value as u32) & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_WS_IN_DELAY` reader - "]
 pub struct I2S_RECE_WS_IN_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_RECE_WS_IN_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_RECE_WS_IN_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +330,14 @@ impl<'a> I2S_RECE_WS_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | (((value as u32) & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
         self.w
     }
 }
 #[doc = "Field `I2S_RECE_BCK_IN_DELAY` reader - "]
 pub struct I2S_RECE_BCK_IN_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_RECE_BCK_IN_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_RECE_BCK_IN_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -344,13 +357,14 @@ impl<'a> I2S_RECE_BCK_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | (((value as u32) & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_WS_IN_DELAY` reader - "]
 pub struct I2S_TRANS_WS_IN_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_TRANS_WS_IN_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_TRANS_WS_IN_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -370,13 +384,14 @@ impl<'a> I2S_TRANS_WS_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | (((value as u32) & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
         self.w
     }
 }
 #[doc = "Field `I2S_TRANS_BCK_IN_DELAY` reader - "]
 pub struct I2S_TRANS_BCK_IN_DELAY_R(crate::FieldReader<u8, u8>);
 impl I2S_TRANS_BCK_IN_DELAY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         I2S_TRANS_BCK_IN_DELAY_R(crate::FieldReader::new(bits))
     }
@@ -396,7 +411,7 @@ impl<'a> I2S_TRANS_BCK_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | ((value as u32) & 0x03);
+        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
         self.w
     }
 }
@@ -534,6 +549,7 @@ impl W {
         I2S_TRANS_BCK_IN_DELAY_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
