@@ -7,12 +7,12 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<RNG_SPEC>> for R {
+impl From<crate::R<RNG_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<RNG_SPEC>) -> Self {
         R(reader)
     }
 }
-impl R {}
 #[doc = "RNG register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rng](index.html) module"]
 pub struct RNG_SPEC;
 impl crate::RegisterSpec for RNG_SPEC {
