@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<SLC_INT_CLR_SPEC>> for R {
+impl From<crate::R<SLC_INT_CLR_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<SLC_INT_CLR_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<SLC_INT_CLR_SPEC>> for W {
+impl From<crate::W<SLC_INT_CLR_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<SLC_INT_CLR_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<SLC_INT_CLR_SPEC>> for W {
 #[doc = "Field `SLC_TX_DSCR_EMPTY_INT_CLR` reader - "]
 pub struct SLC_TX_DSCR_EMPTY_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TX_DSCR_EMPTY_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TX_DSCR_EMPTY_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -64,13 +67,14 @@ impl<'a> SLC_TX_DSCR_EMPTY_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
 #[doc = "Field `SLC_RX_DSCR_ERR_INT_CLR` reader - "]
 pub struct SLC_RX_DSCR_ERR_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_RX_DSCR_ERR_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_RX_DSCR_ERR_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -100,13 +104,14 @@ impl<'a> SLC_RX_DSCR_ERR_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
 #[doc = "Field `SLC_TX_DSCR_ERR_INT_CLR` reader - "]
 pub struct SLC_TX_DSCR_ERR_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TX_DSCR_ERR_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TX_DSCR_ERR_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -136,13 +141,14 @@ impl<'a> SLC_TX_DSCR_ERR_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
 #[doc = "Field `SLC_TOHOST_INT_CLR` reader - "]
 pub struct SLC_TOHOST_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TOHOST_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TOHOST_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -172,13 +178,14 @@ impl<'a> SLC_TOHOST_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
 #[doc = "Field `SLC_RX_EOF_INT_CLR` reader - "]
 pub struct SLC_RX_EOF_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_RX_EOF_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_RX_EOF_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -208,13 +215,14 @@ impl<'a> SLC_RX_EOF_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
 #[doc = "Field `SLC_RX_DONE_INT_CLR` reader - "]
 pub struct SLC_RX_DONE_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_RX_DONE_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_RX_DONE_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -244,13 +252,14 @@ impl<'a> SLC_RX_DONE_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
 #[doc = "Field `SLC_TX_EOF_INT_CLR` reader - "]
 pub struct SLC_TX_EOF_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TX_EOF_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TX_EOF_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -280,13 +289,14 @@ impl<'a> SLC_TX_EOF_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
 #[doc = "Field `SLC_TX_DONE_INT_CLR` reader - "]
 pub struct SLC_TX_DONE_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TX_DONE_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TX_DONE_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -316,13 +326,14 @@ impl<'a> SLC_TX_DONE_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
 #[doc = "Field `SLC_TOKEN1_1TO0_INT_CLR` reader - "]
 pub struct SLC_TOKEN1_1TO0_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TOKEN1_1TO0_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TOKEN1_1TO0_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -352,13 +363,14 @@ impl<'a> SLC_TOKEN1_1TO0_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
 #[doc = "Field `SLC_TOKEN0_1TO0_INT_CLR` reader - "]
 pub struct SLC_TOKEN0_1TO0_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TOKEN0_1TO0_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TOKEN0_1TO0_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -388,13 +400,14 @@ impl<'a> SLC_TOKEN0_1TO0_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
 #[doc = "Field `SLC_TX_OVF_INT_CLR` reader - "]
 pub struct SLC_TX_OVF_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TX_OVF_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TX_OVF_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -424,13 +437,14 @@ impl<'a> SLC_TX_OVF_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
 #[doc = "Field `SLC_RX_UDF_INT_CLR` reader - "]
 pub struct SLC_RX_UDF_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_RX_UDF_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_RX_UDF_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -460,13 +474,14 @@ impl<'a> SLC_RX_UDF_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
 #[doc = "Field `SLC_TX_START_INT_CLR` reader - "]
 pub struct SLC_TX_START_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_TX_START_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_TX_START_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -496,13 +511,14 @@ impl<'a> SLC_TX_START_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
 #[doc = "Field `SLC_RX_START_INT_CLR` reader - "]
 pub struct SLC_RX_START_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_RX_START_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_RX_START_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -532,13 +548,14 @@ impl<'a> SLC_RX_START_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT7_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT7_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT7_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT7_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -568,13 +585,14 @@ impl<'a> SLC_FRHOST_BIT7_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT6_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT6_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT6_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT6_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -604,13 +622,14 @@ impl<'a> SLC_FRHOST_BIT6_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT5_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT5_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT5_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT5_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -640,13 +659,14 @@ impl<'a> SLC_FRHOST_BIT5_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT4_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT4_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT4_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT4_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -676,13 +696,14 @@ impl<'a> SLC_FRHOST_BIT4_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT3_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT3_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT3_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT3_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -712,13 +733,14 @@ impl<'a> SLC_FRHOST_BIT3_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT2_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT2_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT2_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT2_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -748,13 +770,14 @@ impl<'a> SLC_FRHOST_BIT2_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT1_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT1_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT1_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT1_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -784,13 +807,14 @@ impl<'a> SLC_FRHOST_BIT1_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
 #[doc = "Field `SLC_FRHOST_BIT0_INT_CLR` reader - "]
 pub struct SLC_FRHOST_BIT0_INT_CLR_R(crate::FieldReader<bool, bool>);
 impl SLC_FRHOST_BIT0_INT_CLR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLC_FRHOST_BIT0_INT_CLR_R(crate::FieldReader::new(bits))
     }
@@ -820,7 +844,7 @@ impl<'a> SLC_FRHOST_BIT0_INT_CLR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -1048,6 +1072,7 @@ impl W {
         SLC_FRHOST_BIT0_INT_CLR_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
