@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<SPI_SLAVE_SPEC>> for R {
+impl From<crate::R<SPI_SLAVE_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<SPI_SLAVE_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<SPI_SLAVE_SPEC>> for W {
+impl From<crate::W<SPI_SLAVE_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<SPI_SLAVE_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<SPI_SLAVE_SPEC>> for W {
 #[doc = "Field `spi_sync_reset` reader - It is the synchronous reset signal of the module. This bit is self-cleared by hardware."]
 pub struct SPI_SYNC_RESET_R(crate::FieldReader<bool, bool>);
 impl SPI_SYNC_RESET_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_SYNC_RESET_R(crate::FieldReader::new(bits))
     }
@@ -64,13 +67,14 @@ impl<'a> SPI_SYNC_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
         self.w
     }
 }
 #[doc = "Field `spi_slave_mode` reader - 1: slave mode, 0: master mode."]
 pub struct SPI_SLAVE_MODE_R(crate::FieldReader<bool, bool>);
 impl SPI_SLAVE_MODE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_SLAVE_MODE_R(crate::FieldReader::new(bits))
     }
@@ -100,13 +104,14 @@ impl<'a> SPI_SLAVE_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | (((value as u32) & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
         self.w
     }
 }
 #[doc = "Field `slv_cmd_define` reader - 1: slave mode commands are defined in SPI_SLAVE3. 0: slave mode commands are fixed as 1: \"write-status\"; 4: \"read-status\"; 2: \"write-buffer\" and 3: \"read-buffer\"."]
 pub struct SLV_CMD_DEFINE_R(crate::FieldReader<bool, bool>);
 impl SLV_CMD_DEFINE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_CMD_DEFINE_R(crate::FieldReader::new(bits))
     }
@@ -136,13 +141,14 @@ impl<'a> SLV_CMD_DEFINE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
 #[doc = "Field `spi_trans_cnt` reader - The operations counter in both the master mode and the slave mode."]
 pub struct SPI_TRANS_CNT_R(crate::FieldReader<u8, u8>);
 impl SPI_TRANS_CNT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SPI_TRANS_CNT_R(crate::FieldReader::new(bits))
     }
@@ -157,6 +163,7 @@ impl core::ops::Deref for SPI_TRANS_CNT_R {
 #[doc = "Field `spi_int_en` reader - Interrupt enable bits for the below 5 sources"]
 pub struct SPI_INT_EN_R(crate::FieldReader<u8, u8>);
 impl SPI_INT_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SPI_INT_EN_R(crate::FieldReader::new(bits))
     }
@@ -176,13 +183,14 @@ impl<'a> SPI_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x1f << 5)) | (((value as u32) & 0x1f) << 5);
+        self.w.bits = (self.w.bits & !(0x1f << 5)) | ((value as u32 & 0x1f) << 5);
         self.w
     }
 }
 #[doc = "Field `spi_trans_done` reader - The interrupt raw bit for the completement of any operation in both the master mode and the slave mode."]
 pub struct SPI_TRANS_DONE_R(crate::FieldReader<bool, bool>);
 impl SPI_TRANS_DONE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_TRANS_DONE_R(crate::FieldReader::new(bits))
     }
@@ -212,13 +220,14 @@ impl<'a> SPI_TRANS_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
 #[doc = "Field `slv_wr_sta_done` reader - The interrupt raw bit for the completement of \"write-status\" operation in the slave mode."]
 pub struct SLV_WR_STA_DONE_R(crate::FieldReader<bool, bool>);
 impl SLV_WR_STA_DONE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_WR_STA_DONE_R(crate::FieldReader::new(bits))
     }
@@ -248,13 +257,14 @@ impl<'a> SLV_WR_STA_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
 #[doc = "Field `slv_rd_sta_done` reader - The interrupt raw bit for the completement of \"read-status\" operation in the slave mode."]
 pub struct SLV_RD_STA_DONE_R(crate::FieldReader<bool, bool>);
 impl SLV_RD_STA_DONE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_RD_STA_DONE_R(crate::FieldReader::new(bits))
     }
@@ -284,13 +294,14 @@ impl<'a> SLV_RD_STA_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
 #[doc = "Field `slv_wr_buf_done` reader - The interrupt raw bit for the completement of \"write-buffer\" operation in the slave mode."]
 pub struct SLV_WR_BUF_DONE_R(crate::FieldReader<bool, bool>);
 impl SLV_WR_BUF_DONE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_WR_BUF_DONE_R(crate::FieldReader::new(bits))
     }
@@ -320,13 +331,14 @@ impl<'a> SLV_WR_BUF_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
 #[doc = "Field `slv_rd_buf_done` reader - The interrupt raw bit for the completement of \"read-buffer\" operation in the slave mode."]
 pub struct SLV_RD_BUF_DONE_R(crate::FieldReader<bool, bool>);
 impl SLV_RD_BUF_DONE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_RD_BUF_DONE_R(crate::FieldReader::new(bits))
     }
@@ -356,13 +368,14 @@ impl<'a> SLV_RD_BUF_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
 #[doc = "Field `spi_buffer_enable` reader - Enable read/write buffer"]
 pub struct SPI_BUFFER_ENABLE_R(crate::FieldReader<bool, bool>);
 impl SPI_BUFFER_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_BUFFER_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -392,13 +405,14 @@ impl<'a> SPI_BUFFER_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | (((value as u32) & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
         self.w
     }
 }
 #[doc = "Field `sta_enable` reader - Enable read/write buffer"]
 pub struct STA_ENABLE_R(crate::FieldReader<bool, bool>);
 impl STA_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         STA_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -428,13 +442,14 @@ impl<'a> STA_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | (((value as u32) & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
         self.w
     }
 }
 #[doc = "Field `interrupt_trans_enable` reader - Enable TRANS interrupts"]
 pub struct INTERRUPT_TRANS_ENABLE_R(crate::FieldReader<bool, bool>);
 impl INTERRUPT_TRANS_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INTERRUPT_TRANS_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -464,13 +479,14 @@ impl<'a> INTERRUPT_TRANS_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
 #[doc = "Field `interrupt_ws_enable` reader - Enable status write interrupts"]
 pub struct INTERRUPT_WS_ENABLE_R(crate::FieldReader<bool, bool>);
 impl INTERRUPT_WS_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INTERRUPT_WS_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -500,13 +516,14 @@ impl<'a> INTERRUPT_WS_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
 #[doc = "Field `interrupt_rs_enable` reader - Enable status read interrupts"]
 pub struct INTERRUPT_RS_ENABLE_R(crate::FieldReader<bool, bool>);
 impl INTERRUPT_RS_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INTERRUPT_RS_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -536,13 +553,14 @@ impl<'a> INTERRUPT_RS_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
 #[doc = "Field `interrupt_wb_enable` reader - Enable buffer write interrupts"]
 pub struct INTERRUPT_WB_ENABLE_R(crate::FieldReader<bool, bool>);
 impl INTERRUPT_WB_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INTERRUPT_WB_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -572,13 +590,14 @@ impl<'a> INTERRUPT_WB_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
 #[doc = "Field `interrupt_rb_enable` reader - Enable buffer read interrupts"]
 pub struct INTERRUPT_RB_ENABLE_R(crate::FieldReader<bool, bool>);
 impl INTERRUPT_RB_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INTERRUPT_RB_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -608,7 +627,7 @@ impl<'a> INTERRUPT_RB_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -781,6 +800,7 @@ impl W {
         INTERRUPT_RB_ENABLE_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
