@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<SPI_USER_SPEC>> for R {
+impl From<crate::R<SPI_USER_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<SPI_USER_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<SPI_USER_SPEC>> for W {
+impl From<crate::W<SPI_USER_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<SPI_USER_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<SPI_USER_SPEC>> for W {
 #[doc = "Field `spi_usr_command` reader - This bit enable the \"command\" phase of an operation."]
 pub struct SPI_USR_COMMAND_R(crate::FieldReader<bool, bool>);
 impl SPI_USR_COMMAND_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_USR_COMMAND_R(crate::FieldReader::new(bits))
     }
@@ -64,13 +67,14 @@ impl<'a> SPI_USR_COMMAND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
         self.w
     }
 }
 #[doc = "Field `spi_usr_addr` reader - This bit enable the \"address\" phase of an operation."]
 pub struct SPI_USR_ADDR_R(crate::FieldReader<bool, bool>);
 impl SPI_USR_ADDR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_USR_ADDR_R(crate::FieldReader::new(bits))
     }
@@ -100,13 +104,14 @@ impl<'a> SPI_USR_ADDR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | (((value as u32) & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
         self.w
     }
 }
 #[doc = "Field `spi_usr_dummy` reader - This bit enable the \"dummy\" phase of an operation."]
 pub struct SPI_USR_DUMMY_R(crate::FieldReader<bool, bool>);
 impl SPI_USR_DUMMY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_USR_DUMMY_R(crate::FieldReader::new(bits))
     }
@@ -136,13 +141,14 @@ impl<'a> SPI_USR_DUMMY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | (((value as u32) & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
         self.w
     }
 }
 #[doc = "Field `spi_usr_miso` reader - This bit enable the \"read-data\" phase of an operation."]
 pub struct SPI_USR_MISO_R(crate::FieldReader<bool, bool>);
 impl SPI_USR_MISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_USR_MISO_R(crate::FieldReader::new(bits))
     }
@@ -172,13 +178,14 @@ impl<'a> SPI_USR_MISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | (((value as u32) & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
         self.w
     }
 }
 #[doc = "Field `spi_usr_mosi` reader - This bit enable the \"write-data\" phase of an operation."]
 pub struct SPI_USR_MOSI_R(crate::FieldReader<bool, bool>);
 impl SPI_USR_MOSI_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_USR_MOSI_R(crate::FieldReader::new(bits))
     }
@@ -208,13 +215,14 @@ impl<'a> SPI_USR_MOSI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
 #[doc = "Field `reg_usr_mosi_highpart` reader - 1: \"write-data\" phase only access to high-part of the buffer spi_w8~spi_w15"]
 pub struct REG_USR_MOSI_HIGHPART_R(crate::FieldReader<bool, bool>);
 impl REG_USR_MOSI_HIGHPART_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         REG_USR_MOSI_HIGHPART_R(crate::FieldReader::new(bits))
     }
@@ -244,13 +252,14 @@ impl<'a> REG_USR_MOSI_HIGHPART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | (((value as u32) & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
         self.w
     }
 }
 #[doc = "Field `reg_usr_miso_highpart` reader - 1: \"read-data\" phase only access to high-part of the buffer spi_w8~spi_w15"]
 pub struct REG_USR_MISO_HIGHPART_R(crate::FieldReader<bool, bool>);
 impl REG_USR_MISO_HIGHPART_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         REG_USR_MISO_HIGHPART_R(crate::FieldReader::new(bits))
     }
@@ -280,13 +289,14 @@ impl<'a> REG_USR_MISO_HIGHPART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
 #[doc = "Field `spi_sio` reader - 1: mosi and miso signals share the same pin"]
 pub struct SPI_SIO_R(crate::FieldReader<bool, bool>);
 impl SPI_SIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_SIO_R(crate::FieldReader::new(bits))
     }
@@ -316,13 +326,14 @@ impl<'a> SPI_SIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
 #[doc = "Field `spi_fwrite_qio` reader - In the write operations, \"address\" phase and \"read-data\" phase apply 4 signals"]
 pub struct SPI_FWRITE_QIO_R(crate::FieldReader<bool, bool>);
 impl SPI_FWRITE_QIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_FWRITE_QIO_R(crate::FieldReader::new(bits))
     }
@@ -352,13 +363,14 @@ impl<'a> SPI_FWRITE_QIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
 #[doc = "Field `spi_fwrite_dio` reader - In the write operations, \"address\" phase and \"read-data\" phase apply 2 signals"]
 pub struct SPI_FWRITE_DIO_R(crate::FieldReader<bool, bool>);
 impl SPI_FWRITE_DIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_FWRITE_DIO_R(crate::FieldReader::new(bits))
     }
@@ -388,13 +400,14 @@ impl<'a> SPI_FWRITE_DIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
 #[doc = "Field `spi_fwrite_quad` reader - In the write operations, \"read-data\" phase apply 4 signals"]
 pub struct SPI_FWRITE_QUAD_R(crate::FieldReader<bool, bool>);
 impl SPI_FWRITE_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_FWRITE_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -424,13 +437,14 @@ impl<'a> SPI_FWRITE_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
 #[doc = "Field `spi_fwrite_dual` reader - In the write operations, \"read-data\" phase apply 2 signals"]
 pub struct SPI_FWRITE_DUAL_R(crate::FieldReader<bool, bool>);
 impl SPI_FWRITE_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_FWRITE_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -460,13 +474,14 @@ impl<'a> SPI_FWRITE_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
 #[doc = "Field `spi_wr_byte_order` reader - In \"command\", \"address\", \"write-data\" (MOSI) phases, 1: little-endian; 0: big_endian"]
 pub struct SPI_WR_BYTE_ORDER_R(crate::FieldReader<bool, bool>);
 impl SPI_WR_BYTE_ORDER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_WR_BYTE_ORDER_R(crate::FieldReader::new(bits))
     }
@@ -496,13 +511,14 @@ impl<'a> SPI_WR_BYTE_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
 #[doc = "Field `spi_rd_byte_order` reader - In \"read-data\" (MISO) phase, 1: little-endian; 0: big_endian"]
 pub struct SPI_RD_BYTE_ORDER_R(crate::FieldReader<bool, bool>);
 impl SPI_RD_BYTE_ORDER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_RD_BYTE_ORDER_R(crate::FieldReader::new(bits))
     }
@@ -532,13 +548,14 @@ impl<'a> SPI_RD_BYTE_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
 #[doc = "Field `spi_ck_i_edge` reader - In the slave mode, 1: rising-edge; 0: falling-edge"]
 pub struct SPI_CK_I_EDGE_R(crate::FieldReader<bool, bool>);
 impl SPI_CK_I_EDGE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_CK_I_EDGE_R(crate::FieldReader::new(bits))
     }
@@ -568,13 +585,14 @@ impl<'a> SPI_CK_I_EDGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
 #[doc = "Field `spi_ck_o_edge` reader - In the master mode, 1: rising-edge; 0: falling-edge"]
 pub struct SPI_CK_O_EDGE_R(crate::FieldReader<bool, bool>);
 impl SPI_CK_O_EDGE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_CK_O_EDGE_R(crate::FieldReader::new(bits))
     }
@@ -604,13 +622,14 @@ impl<'a> SPI_CK_O_EDGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
 #[doc = "Field `spi_cs_setup` reader - spi cs is enable when spi is in prepare phase. 1: enable 0: disable."]
 pub struct SPI_CS_SETUP_R(crate::FieldReader<bool, bool>);
 impl SPI_CS_SETUP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_CS_SETUP_R(crate::FieldReader::new(bits))
     }
@@ -640,13 +659,14 @@ impl<'a> SPI_CS_SETUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
 #[doc = "Field `spi_cs_hold` reader - spi cs keep low when spi is in done phase. 1: enable 0: disable."]
 pub struct SPI_CS_HOLD_R(crate::FieldReader<bool, bool>);
 impl SPI_CS_HOLD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_CS_HOLD_R(crate::FieldReader::new(bits))
     }
@@ -676,13 +696,14 @@ impl<'a> SPI_CS_HOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
 #[doc = "Field `spi_ahb_user_command` reader - reserved"]
 pub struct SPI_AHB_USER_COMMAND_R(crate::FieldReader<bool, bool>);
 impl SPI_AHB_USER_COMMAND_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_AHB_USER_COMMAND_R(crate::FieldReader::new(bits))
     }
@@ -712,13 +733,14 @@ impl<'a> SPI_AHB_USER_COMMAND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
 #[doc = "Field `spi_flash_mode` reader - "]
 pub struct SPI_FLASH_MODE_R(crate::FieldReader<bool, bool>);
 impl SPI_FLASH_MODE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_FLASH_MODE_R(crate::FieldReader::new(bits))
     }
@@ -748,13 +770,14 @@ impl<'a> SPI_FLASH_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
 #[doc = "Field `spi_ahb_user_command_4byte` reader - reserved"]
 pub struct SPI_AHB_USER_COMMAND_4BYTE_R(crate::FieldReader<bool, bool>);
 impl SPI_AHB_USER_COMMAND_4BYTE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_AHB_USER_COMMAND_4BYTE_R(crate::FieldReader::new(bits))
     }
@@ -784,13 +807,14 @@ impl<'a> SPI_AHB_USER_COMMAND_4BYTE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
 #[doc = "Field `spi_duplex` reader - set spi in full duplex mode"]
 pub struct SPI_DUPLEX_R(crate::FieldReader<bool, bool>);
 impl SPI_DUPLEX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_DUPLEX_R(crate::FieldReader::new(bits))
     }
@@ -820,7 +844,7 @@ impl<'a> SPI_DUPLEX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -1048,6 +1072,7 @@ impl W {
         SPI_DUPLEX_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
