@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<UART_CONF0_SPEC>> for R {
+impl From<crate::R<UART_CONF0_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<UART_CONF0_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<UART_CONF0_SPEC>> for W {
+impl From<crate::W<UART_CONF0_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<UART_CONF0_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<UART_CONF0_SPEC>> for W {
 #[doc = "Field `uart_dtr_inv` reader - Set this bit to inverse uart dtr level"]
 pub struct UART_DTR_INV_R(crate::FieldReader<bool, bool>);
 impl UART_DTR_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_DTR_INV_R(crate::FieldReader::new(bits))
     }
@@ -64,13 +67,14 @@ impl<'a> UART_DTR_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
 #[doc = "Field `uart_rts_inv` reader - Set this bit to inverse uart rts level"]
 pub struct UART_RTS_INV_R(crate::FieldReader<bool, bool>);
 impl UART_RTS_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_RTS_INV_R(crate::FieldReader::new(bits))
     }
@@ -100,13 +104,14 @@ impl<'a> UART_RTS_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | (((value as u32) & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
         self.w
     }
 }
 #[doc = "Field `uart_txd_inv` reader - Set this bit to inverse uart txd level"]
 pub struct UART_TXD_INV_R(crate::FieldReader<bool, bool>);
 impl UART_TXD_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_TXD_INV_R(crate::FieldReader::new(bits))
     }
@@ -136,13 +141,14 @@ impl<'a> UART_TXD_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
 #[doc = "Field `uart_dsr_inv` reader - Set this bit to inverse uart dsr level"]
 pub struct UART_DSR_INV_R(crate::FieldReader<bool, bool>);
 impl UART_DSR_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_DSR_INV_R(crate::FieldReader::new(bits))
     }
@@ -172,13 +178,14 @@ impl<'a> UART_DSR_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
 #[doc = "Field `uart_cts_inv` reader - Set this bit to inverse uart cts level"]
 pub struct UART_CTS_INV_R(crate::FieldReader<bool, bool>);
 impl UART_CTS_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_CTS_INV_R(crate::FieldReader::new(bits))
     }
@@ -208,13 +215,14 @@ impl<'a> UART_CTS_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
 #[doc = "Field `uart_rxd_inv` reader - Set this bit to inverse uart rxd level"]
 pub struct UART_RXD_INV_R(crate::FieldReader<bool, bool>);
 impl UART_RXD_INV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_RXD_INV_R(crate::FieldReader::new(bits))
     }
@@ -244,13 +252,14 @@ impl<'a> UART_RXD_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
 #[doc = "Field `txfifo_rst` reader - Set this bit to reset uart tx fifo"]
 pub struct TXFIFO_RST_R(crate::FieldReader<bool, bool>);
 impl TXFIFO_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TXFIFO_RST_R(crate::FieldReader::new(bits))
     }
@@ -280,13 +289,14 @@ impl<'a> TXFIFO_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
 #[doc = "Field `rxfifo_rst` reader - Set this bit to reset uart rx fifo"]
 pub struct RXFIFO_RST_R(crate::FieldReader<bool, bool>);
 impl RXFIFO_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RXFIFO_RST_R(crate::FieldReader::new(bits))
     }
@@ -316,13 +326,14 @@ impl<'a> RXFIFO_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
 #[doc = "Field `tx_flow_en` reader - Set this bit to enable uart tx hardware flow control"]
 pub struct TX_FLOW_EN_R(crate::FieldReader<bool, bool>);
 impl TX_FLOW_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TX_FLOW_EN_R(crate::FieldReader::new(bits))
     }
@@ -352,13 +363,14 @@ impl<'a> TX_FLOW_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
 #[doc = "Field `uart_loopback` reader - Set this bit to enable uart loopback test mode"]
 pub struct UART_LOOPBACK_R(crate::FieldReader<bool, bool>);
 impl UART_LOOPBACK_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_LOOPBACK_R(crate::FieldReader::new(bits))
     }
@@ -388,13 +400,14 @@ impl<'a> UART_LOOPBACK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
 #[doc = "Field `txd_brk` reader - RESERVED, DO NOT CHANGE THIS BIT"]
 pub struct TXD_BRK_R(crate::FieldReader<bool, bool>);
 impl TXD_BRK_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TXD_BRK_R(crate::FieldReader::new(bits))
     }
@@ -424,13 +437,14 @@ impl<'a> TXD_BRK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
 #[doc = "Field `sw_dtr` reader - sw dtr"]
 pub struct SW_DTR_R(crate::FieldReader<bool, bool>);
 impl SW_DTR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SW_DTR_R(crate::FieldReader::new(bits))
     }
@@ -460,13 +474,14 @@ impl<'a> SW_DTR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
 #[doc = "Field `sw_rts` reader - sw rts"]
 pub struct SW_RTS_R(crate::FieldReader<bool, bool>);
 impl SW_RTS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SW_RTS_R(crate::FieldReader::new(bits))
     }
@@ -496,13 +511,14 @@ impl<'a> SW_RTS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
 #[doc = "Field `stop_bit_num` reader - Set stop bit: 1:1bit 2:1.5bits 3:2bits"]
 pub struct STOP_BIT_NUM_R(crate::FieldReader<u8, u8>);
 impl STOP_BIT_NUM_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         STOP_BIT_NUM_R(crate::FieldReader::new(bits))
     }
@@ -522,13 +538,14 @@ impl<'a> STOP_BIT_NUM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | (((value as u32) & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
         self.w
     }
 }
 #[doc = "Field `bit_num` reader - Set bit num: 0:5bits 1:6bits 2:7bits 3:8bits"]
 pub struct BIT_NUM_R(crate::FieldReader<u8, u8>);
 impl BIT_NUM_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         BIT_NUM_R(crate::FieldReader::new(bits))
     }
@@ -548,13 +565,14 @@ impl<'a> BIT_NUM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | (((value as u32) & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
         self.w
     }
 }
 #[doc = "Field `parity_en` reader - Set this bit to enable uart parity check"]
 pub struct PARITY_EN_R(crate::FieldReader<bool, bool>);
 impl PARITY_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PARITY_EN_R(crate::FieldReader::new(bits))
     }
@@ -584,13 +602,14 @@ impl<'a> PARITY_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
 #[doc = "Field `parity` reader - Set parity check: 0:even 1:odd, UART CONFIG1"]
 pub struct PARITY_R(crate::FieldReader<bool, bool>);
 impl PARITY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PARITY_R(crate::FieldReader::new(bits))
     }
@@ -620,7 +639,7 @@ impl<'a> PARITY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -798,6 +817,7 @@ impl W {
         PARITY_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
